/*
 * tuner.c: Routines to communicate with a tuner connected to a VTX-card's IC-Bus
 *
 * Copyright (c) 1994-96 Martin Buck  <martin-2.buck@student.uni-ulm.de>
 * Read COPYING for more information
 *
 */

#include <unistd.h>
#include <fcntl.h>
#include <errno.h>
#include <sys/ioctl.h>
#include <sys/vtx.h>
#include "tuner.h"


char *tuner_device = "/dev/tuner";

static int tunfd = -1;



/*
 */
int
tuner_open(int major, int minor, tuner_info_t *prg_info) {
  tuner_info_t *info, tmp_info;
  
  if ((tunfd = open(tuner_device, O_RDONLY)) < 0)
    return TUNEOPEN;
  info = (prg_info != NULL ? prg_info : &tmp_info);
  if (ioctl(tunfd, TUNIOCGETINFO, info) < 0)
    return TUNERR;
  if (info->version_major != major || info->version_minor < minor) {
    while (close(tunfd) < 0 && errno == EINTR);
    tunfd = -1;
    return TUNEVERSION;
  }
  return TUNOK;
}


/*
 */
void
tuner_close(void) {
  if (tunfd == -1)
    return;
  while (close(tunfd) < 0 && errno == EINTR);
  tunfd = -1;
}


/*
 */
int
tuner_reset(void) {
  if (tunfd == -1)
    return TUNEOPEN;
  if (ioctl(tunfd, TUNIOCRESET) < 0)
    return TUNERR;
  return TUNOK;
}


/*
 */
int
tuner_setfreq(unsigned int freq) {
  int err;
  
  if (tunfd == -1)
    return TUNEOPEN;
  if ((err = ioctl(tunfd, TUNIOCSETFREQ, (unsigned int)freq)) < 0) {
    if (errno == EINVAL)
      return TUNEINVAL;
    return TUNERR;
  }
  return TUNOK;
}


/*
 */
int
tuner_getfreq(void) {
  int freq;
  
  if (tunfd == -1)
    return TUNEOPEN;
  if (ioctl(tunfd, TUNIOCGETFREQ, &freq) < 0)
    return TUNERR;
  return freq;
}
